const swaggerJSDoc = require('swagger-jsdoc')
const swaggerUi = require('swagger-ui-express')

const express = require('express')
const bodyParser = require('body-parser')
const morgan = require('morgan')

//Routes
const cargaRouter = require('../routes/carga-router')
const usuarioRouter = require('../routes/usuario-router')
const consultaRouter = require('../routes/consulta-router')

const swaggerDefinition = {
    info: {
        title: 'API Dolphin Cargas',
        version: '1.0.0',
        description: 'API REST para comunicación del Módulo de Cargas de Dolphin'
    },
    host: 'localhost:3000',
    basePath: '/api',
}

const options = {
    swaggerDefinition,
    apis: ['./routes/*.js'],
}

//Criando/Invocando a Api/Server Web do Express
const app = express()

//Configuração de Parse de JSON.
app.use(bodyParser
    .json({limit: '50mb', extended: true}));
app.use(bodyParser
    .urlencoded({limit: '50mb', extended: true}));
app.use(morgan(`combined`))

// Habilita o CORS
app.use(function (req, res, next) {
    res.header('Access-Control-Allow-Origin', '*');
    res.header('Access-Control-Allow-Headers', 'Origin, X-Requested-With, Content-Type, Accept, x-access-token, schema');
    res.header('Access-Control-Allow-Methods', 'GET, POST, PUT, DELETE, OPTIONS');
    next();
});

//Configurando as Rotas
app.use('/api/cargas', cargaRouter)
app.use('/api/usuarios', usuarioRouter)
app.use('/api/consultas', consultaRouter)

const swaggerSpec = swaggerJSDoc(options)
app.get('/swagger.json', function (req, res) {
    res.setHeader('Content-Type', 'application/json');
    res.send(swaggerSpec);
})

app.use('/api-docs', swaggerUi.serve, swaggerUi.setup(swaggerSpec))

module.exports = app
