'use strict'

const validation = require('./validation')

class ValidaCarga {
    constructor(req) {
        this._validationContract = new validation()
        this.isCargaValid(req.body.cargas)
    }

    isCargaValid(carga) {
        this._validationContract.isArray(carga)

        if (!this._validationContract.isValid()) {
            return
        }

        let contadorCarga = 1
        carga.forEach(c => {

            this._validationContract.isRequired(c.cod_tp_carga, this.getMessageRequerido('cod_tp_carga', contadorCarga))
            this._validationContract.isRequired(c.cod_localidad, this.getMessageRequerido('cod_localidad', contadorCarga))
            this._validationContract.isRequired(c.fe_emision, this.getMessageRequerido('fe_emision', contadorCarga))
            this._validationContract.isRequired(c.cod_mercaderia, this.getMessageRequerido('cod_mercaderia', contadorCarga))
            this._validationContract.isRequired(c.cod_entidad, this.getMessageRequerido('cod_entidad', contadorCarga))
            this._validationContract.isRequired(c.cod_silo, this.getMessageRequerido('cod_silo', contadorCarga))
            this._validationContract.isRequired(c.cod_plan_financ, this.getMessageRequerido('cod_plan_financ', contadorCarga))

            // todo validadores
            // todo 1. validar mercadoria pertencente ao plano
            // todo 2. validar contrato de entidade
            // todo 3. validar despacho de entidade
            if (this._validationContract.isValid()) {

                switch (c.cod_tp_carga) {
                    case 4:
                        this.isRemisionValid(c, contadorCarga)
                        break
                    case 7:
                        this.isRomaneioValid(c, contadorCarga)
                        break
                    case 10:
                        this.isRomaneioPorContratoValid(c, contadorCarga)
                        break
                    case 11:
                        this.isRemisionPorContratoValid(c, contadorCarga)
                        break
                }
            }

            contadorCarga++;
        })
    }

    isFechamentoEntradaValid(romaneio, contadorCarga) {
        //CSITUANCA --situ_analise
        //NCODICFCA --cod_classificacao
        //"entrada_saida_analise": "censaanca",
        //cod_analista -- NCODIUSUA_ANCA

    }

    isFechamentoSaidaValid(remision, contadorCarga) {
        //CSITUANCA --situ_analise
        //NCODICFCA --cod_classificacao
        //"entrada_saida_analise": "censaanca",
        //cod_analista -- NCODIUSUA_ANCA

    }

    isEntradaValid(romaneio, contadorCarga) {
        this._validationContract.isRequired(romaneio.cod_contrato, this.getMessageRequerido('cod_contrato', contadorCarga))
        // this._validationContract.isRequired(romaneio.tp_neg_flete, this.getMessageRequerido('tp_neg_flete', contadorCarga))
        // this._validationContract.isGreaterThen(romaneio.tp_neg_flete, 0, this.getMessageRequerido('tp_neg_flete', contadorCarga))

    }

    isSaidaValid(remision, contadorCarga) {
        // this._validationContract.isRequired(remision.ctpngcarg, '[tipo_negociacao] TIPO DE NEGOCIACAO é requerido.')
        // this._validationContract.isRequired(remision.tp_neg_flete, this.getMessageRequerido('tp_neg_flete', contadorCarga))
        // this._validationContract.isGreaterThen(remision.tp_neg_flete, 0, this.getMessageRequerido('tp_neg_flete', contadorCarga))
    }

    isRomaneioValid(romaneio, contadorCarga) {
        this.isEntradaValid(romaneio, contadorCarga)
    }

    isRomaneioPorContratoValid(romaneioPorContrato, contadorCarga) {
        this.isEntradaValid(romaneioPorContrato, contadorCarga)
    }

    isRemisionValid(remision, contadorCarga) {
        this.isSaidaValid(remision, contadorCarga)
    }

    isRemisionPorContratoValid(remisionPorContrato, contadorCarga) {
        this.isSaidaValid(remisionPorContrato, contadorCarga)
    }

    isValid() {
        return this._validationContract.isValid()
    }

    errors() {
        return this._validationContract.errors()
    }

    getMessageString(field, num_sequence) {
        return `[${field}] de la carga ${num_sequence} debe ser del tipo (string)`;
    }

    getMessageRequerido(field, num_sequence) {
        return `[${field}] de la carga ${num_sequence} es requerido`;
    }
}

module.exports = ValidaCarga
