'use strict';

const { ExecuteError } = require(`../../models/retorno-model`)

class ValidationContract {
    constructor() {
        this._errors = [];
    }

    isNotArrayOrEmpty(value, message) {
        if (!value && value.length == 0)
            this.   pushErrors({message: message});
    }

    isTrue(value, message) {
        if (value)
            this.pushErrors({message: message});
    }

    isRequired(value, message) {
        if (!value || value.length <= 0)
            this.pushErrors({message: message});
    }

    isGreaterThen(value, min, message) {
        if (!value || value < min)
            this.pushErrors({message: message});
    }

    hasMinLen(value, min, message) {
        if (!value || value.length < min)
            this.pushErrors({message: message});
    }

    hasMaxLen(value, max, message) {
        if (!value || value.length > max)
            this.pushErrors({message: message});
    }

    isFixedLen(value, len, message) {
        if (value.length != len)
            this.pushErrors({message: message});
    }

    isEmail(value, message) {
        var reg = new RegExp(/^\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*$/);
        if (!reg.test(value))
            this.pushErrors({message: message});
    }

    isArray(value) {
        if (!Array.isArray(value)) {
            this.pushErrors({message: `JSON de entrada deve ser um array "[]"`})
        }
    }

    isString(value, message) {
        if(typeof value != "string") {
            this.pushErrors({message: message})
        }
    }

    pushErrors(message) {
        this._errors.push(new ExecuteError(422, message.message))
    }

    errors() {
        return this._errors;
    }

    clear() {
        this._errors = [];
    }

    isValid() {
        return this._errors.length == 0;
    }
}

module.exports = ValidationContract;
