"use strict"

const repository = require("../repositories/consulta-repository")
const variables = require('../bin/configuration/variables')
const validation = require('../bin/helpers/validation')

class consultaController {

    constructor() {
    }

    static checkSchema(req) {
        let validationContract = new validation()
        let schema = req.hasOwnProperty('usuarioLogado') ? req.usuarioLogado.schema : req.headers.hasOwnProperty('schema') ? req.headers.schema : null
        validationContract.isRequired(schema, '[HEADER-SCHEMA] debes informar un valor para "schema" en header de la requisición.')
        if (!validationContract.isValid()) {
            throw validationContract.errors();
        }
    }

    static createRepository(req) {
        let schema = req.hasOwnProperty('usuarioLogado') ? req.usuarioLogado.schema : req.headers.schema
        let repo = new repository()
        let database_config = {schema: schema}
        repo.setDatabaseConfig(database_config)
        return repo
    }

    static async getConsulta(req, res, module) {
        try {
            this.checkSchema(req);
            let _repo = this.createRepository(req)
            let resultado = await _repo.find(module)
            res.status(200).send(resultado)
        } catch (err) {
            console.error(`error en la consulta del modulo ${module}, motivo:`, err)
            res.status(500).send({
                message: 'error en el procesamiento',
                errores: err
            })
        }
    }

    static async getConsultaById(req, res, module) {
        try {
            this.checkSchema(req);
            let _repo = this.createRepository(req)
            let id = req.params.id || req.params.token
            if (id) {
                let resultado = await _repo.findById(module, id)
                res.status(200).send(resultado)
            } else {
                res.status(400).send({
                    message: 'El parámetro Id necesita ser informado.'
                })
            }
        } catch (err) {
            console.error(`error en la consulta por ID del modulo ${module}, motivo:`, err)
            res.status(500).send({
                message: 'Error en el procesamiento',
                error: err
            })
        }
    }

    async getPlano(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.planoFinanciamento);
    }

    async getPlanoById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.planoFinanciamento)
    }

    async getMercadoria(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.mercadoria)
    }

    async getMercadoriaById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.mercadoria)
    }

    async getLocalidade(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.localidade)
    }

    async getLocalidadeById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.localidade)
    }

    async getFilial(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.filial)
    }

    async getFilialById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.filial)
    }

    async getDepartamento(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.departamento)
    }

    async getDepartamentoById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.departamento)
    }

    async getVariedade(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.variedade)
    }

    async getVariedadeById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.variedade)
    }

    async getSilo(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.silo)
    }

    async getSiloById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.silo)
    }

    async getEntidade(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.entidade)
    }

    async getEntidadeById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.entidade)
    }

    async getSchema(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.schema)
    }

    async getProcesso(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.processo)
    }

    async getProcessoById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.processo)
    }

    async getTipoCargas(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.tipoCargas)
    }

    async getTipoCargasById(req, res) {
        await consultaController.getConsultaById(req, res, variables.Module.tipoCargas)
    }

    async getAnalistaCargas(req, res) {
        await consultaController.getConsulta(req, res, variables.Module.entidadeAnalista)
    }
}

module.exports = consultaController
