"use strict"

const repository = require("../repositories/usuario-repository")
const validation = require('../bin/helpers/validation')
const jwt = require('jsonwebtoken')
const variables = require('../bin/configuration/variables')

class usuarioController {
    constructor() {
    }

    async autenticar(req, res) {
        let _validationContract = new validation()
        let usuarioEncontrado = {}

        _validationContract.isRequired(req.headers.schema, '[HEAD-ERROR] debes informar un valor para "schema" en header de la requisición.')
        _validationContract.isRequired(req.body.schema, 'Informe la base de datos')
        _validationContract.isRequired(req.body.login, 'Informe seu login')
        _validationContract.isRequired(req.body.password, 'Informe sua senha')
        _validationContract.isRequired(req.body.sucursal, 'Informe la sucursal')
        _validationContract.isRequired(req.body.departamento, 'Informe el departamento')

        if (!_validationContract.isValid()) {
            res.status(400).send({
                message: `No es posible realizar la entrada`,
                validation: _validationContract.errors()
            })
            return
        }

        let _repo = new repository()
        await _repo.setDatabaseConfig({schema: req.headers.schema})

        try {
            usuarioEncontrado = await _repo.authenticate(req.body)
        } catch (error) {
            res.status(500).send({errores: [{codigo: 500, mensaje: error.message}]})
                .end()
            return
        }

        if (usuarioEncontrado) {
            res.status(200).send({
                ...usuarioEncontrado,
                accessToken: jwt.sign({user: {...usuarioEncontrado}}, variables.Security.secretkey, {expiresIn: '1h'})
            })
        } else {
            res.status(404).send({errores: [{code: 500, mensaje: 'Usuario o Contraseña informado no es valido'}]})
        }
    }
}

module.exports = usuarioController
