"use strict"

const oracledb = require('oracledb')
const variables = require('../bin/configuration/variables')
const base = require('../bin/base/repository-base')
const {
    PLSQL_PROCESSA_CARGA, CARGA_BINDING_IN_META, CARGA_BINDING_OUT,
    SQL_CARGA_INSERT, DESCONTO_BINDING_IN_META, SQL_DESCONTO_INSERT,
    SQL_GET_CARGAS_FINALIZADAS, START_PROCESS
} = require('../builder/carga-builder')

class cargaRepository extends base {

    constructor() {
        super()
    }

    async get(connection) {
        let retorno = {}

        let options = {
            autoCommit: true,
            batchErrors: false,
            outFormat: oracledb.OBJECT
        }

        await connection.execute(SQL_GET_CARGAS_FINALIZADAS, [], options)
            .then((result) => {
                retorno = result.rows
            })
            .catch(e => {
                console.error('error connection.execute ->', e)
                retorno = {
                    CODE: e.errorCode,
                    MSG: e.message
                }
            })

        return retorno
    }

    async startProcess(token, total_cargas, isTrade, cargaDto) {
        let retorno = {}
        let options = {autoCommit: true}
        let connection = await this.getConnection()

        try {
            await connection.execute(START_PROCESS, [token, Number(total_cargas), (isTrade ? 'S' : 'N'), JSON.stringify(cargaDto, null, 4)], options)
            retorno = {CODE: 200, MSG: `Proceso iniciado...`}
        } catch (e) {
            retorno = {CODE: e.errorCode, MSG: e.message}
            console.error("execution error -> ", e, '\nsql -> ', START_PROCESS, '\n cargas -> ', {
                token: token,
                total_cargas: total_cargas
            });
        }

        return retorno
    }

    async findById(id) {
        let retorno = {}
        const binds = [id]
        var sql = `select * from BALCARG where NCODICARG = :1`

        let connection = await this.getConnection()

        await connection.execute(sql, binds, {outFormat: oracledb.OBJECT})
            .then((result) => {
                retorno = result.rows
            })
            .catch((err) => {
                retorno = err.toString()
                console.error(`ERRO execute FINDBYID`, err)
            })

        return retorno
    }

    async compareMetaInsertCarga(cargas, meta) {
        if ( variables.ExecutionMode === 'debug' ) {
            let content = []
            for (const carga of cargas) {
                await Object.keys(meta).forEach(key => {
                    let index = Object.keys(carga).findIndex(indx => indx.toLowerCase() === key.toLowerCase())
                    if (index > -1) {
                        content.push({key: key, value: carga[key], meta: key, type: meta[key].typeIn})
                    } else {
                        content.push({key: index, value: null, meta: key, type: meta[key].typeIn})
                    }
                })
            }
            console.warn('=====================================================Compare=====================================================')
            await content.forEach(o => console.log(JSON.stringify(o)))
        }
        // console.warn('=====================================================String=====================================================')
        // await content.filter(c => c.type === 'String').forEach(o => console.log(o))
        // console.warn('=====================================================Date=====================================================')
        // await content.filter(c => c.type === 'Date').forEach(o => console.log(o))
        // console.warn('=====================================================Number=====================================================')
        // await content.filter(c => c.type === 'Number').forEach(o => console.log(o))
        // console.warn('=====================================================Not Null=====================================================')
        // await content.filter(c => c.value != null).forEach(o => console.log(o))
        // console.warn('=====================================================null=====================================================')
        // await content.filter(c => c.value === null || c.value === '' || c.value === "").forEach(o => console.log(o))
        // console.warn(cargas)
    }

    async insert_carga(cargas, connection) {
        let retorno = {}

        const localOptions = {autoCommit: false, batchErrors: true, bindDefs: CARGA_BINDING_IN_META}

        try {
            this.compareMetaInsertCarga(cargas, CARGA_BINDING_IN_META);

            await connection.executeMany(SQL_CARGA_INSERT, cargas, localOptions)
            retorno.CODE = 200
            retorno.MSG = `Cargas disponíbles para procesamiento`
        } catch (e) {
            retorno = {
                CODE: e.errorCode,
                MSG: e.message
            }
            console.error(`execution error insert_carga -> ${e} '\n cargas -> ${JSON.stringify(cargas)}`);
        }

        return retorno
    }

    async insert_descontos(descontos, connection) {
        let retorno = {}

        let options = {
            autoCommit: false,
            batchErrors: true,
            bindDefs: DESCONTO_BINDING_IN_META
        }

        try {
            await
                connection.executeMany(SQL_DESCONTO_INSERT, descontos, options)
            retorno = {
                CODE: 200,
                MSG: `Descuentos disponibles procesamiento`
            }
        } catch (e) {
            retorno = {
                CODE: e.errorCode,
                MSG: e.message
            }
        }

        return retorno
    }

    async pocessa_pacote(token, connection) {
        let retorno = {}
        let data_in = {
            TOKEN_IN: token,
            ...CARGA_BINDING_OUT
        }

        let options = {
            autoCommit: false,
            bindDefs: {
                TOKEN_IN: {type: oracledb.STRING, dir: oracledb.BIND_IN},
                ...CARGA_BINDING_OUT
            }
        }

        try {
            retorno = await connection.execute(PLSQL_PROCESSA_CARGA, data_in, options)

            retorno = {
                CODE: retorno.outBinds.RETORNO_CODE,
                MSG: retorno.outBinds.RETORNO_MSG
            }

        } catch (e) {
            retorno = {
                CODE: e.errorCode,
                MSG: e.message
            }
        }

        return retorno
    }
}

module.exports = cargaRepository
