#!/bin/bash

###################
#    API CARGAS   # 
#####VARIABLES#####

basePath="/root/datapar/etl"
##GIT##
liquidetlapicargas="liquidetl-api-cargas"
liquidetltransformer="liquidetl-transformer"
liquidetlfrontend="liquidetl-frontend"
currentBranch="release/1.0.2-cargas.api"
##PORTAS##
apiCargasPort=3000
apiTransformationPort=3450
frontPort=7000
##BASE##
baseOracle=oracle-desenv-11g.vm.datapar.com/DOPR
instalarNode=n
instalarGit=n
instalarOracle=n
versaoSO=6
oracleVersion=11
fileRepoPath=/root/datapar
#######REPOSITORY#######
repo_cliente=""
artifactoryRepo=http://maestro.datapar.com/artifactory/list/instaladores/LIQUIDETL
clientOracle10g=oracle-instantclient-basic-10.2.0.5-1.x86_64.rpm
clientOracle11g=oracle-instantclient11.2-basic-11.2.0.4.0-1.x86_64.rpm
liquidApiCargaRepo=liquidEtlApiCarga.zip
liquidApiTransformerRepo=liquidEtlTransform.zip
liquidFrontRepo=liquidEtlFront.zip
userArtifactoryToken=AP5SG3NnV3t3EyGxyzHdoN7aHQ1

#####BODY#####
doInstallNode() {
    if [ "$instalarNode" == "s" ]
    then
        yum install -y gcc-c++ make
        yum install -y oracle-nodejs-release-el$versaoSO oracle-release-el$versaoSO
        curl -sL https://rpm.nodesource.com/setup_10.x | sudo -E bash -
        yum install -y nodejs
    fi
}


createEnvironmentFile() {
    cd /etc/profiles.d
    touch etl.sh

    echo "#!/bin/bash">>etl.sh
    echo "export ApiCargasConnection=$baseOracle">>etl.sh
    echo "export ApiCargasUser=dolphin">>etl.sh
    echo "export ApiCargasPort=$apiCargasPort">>etl.sh
    echo "export TransformationFilePath=$fileRepoPath">>etl.sh
    echo "export TransformationPort=$apiTransformationPort">>etl.sh
    echo "export ConfigTransformation=$basePath/$liquidetltransformer/transformation.env">>etl.sh
    echo "export LD_LIBRARY_PATH=$oracleClientPath/lib">>etl.sh
    echo "export PATH=$oracleClientPath/bin:$PATH">>etl.sh

    chmod 755 etl.sh

    export TransformationFilePath=$fileRepoPath
    export TransformationPort=$apiTransformationPort
    export ConfigTransformation=$basePath/$liquidetltransformer/transformation.env
    export ApiCargasConnection=$baseOracle
    export ApiCargasUser=dolphin
    export ApiCargasPort=$apiCargasPort
    export LD_LIBRARY_PATH=$oracleClientPath/lib
    export PATH=$oracleClientPath/bin:$PATH 

    cd $basePath
}

startServices() {
 cd $basePath

 ./startApiCarga.sh
 pm2 save
 pm2 start startTransformer.sh --name Api.Transformer --watch true --log $basePath/Api.Transformer.log
 pm2 save
 pm2 start startLiquidEtlFront.sh --name liquidEtl-Frontend --watch true --log liquidEtl-Frontend.log
 pm2 save
 
 #pm2 startup
}


configApiCarga() {
    cd $basePath
    echo "#!/bin/bash">>startApiCarga.sh
    echo "cd $basePath/$liquidetlapicargas">>startApiCarga.sh
    echo "pm2 start --name Api.Cargas --watch true --log Api.Cargas server.js">>startApiCarga.sh
    chmod +x startApiCarga.sh    
}

configApiTransformation() {
    cd $basePath
    echo "#!/bin/bash">>startTransformer.sh
    echo "cd $basePath/$liquidetltransformer">>startTransformer.sh
    echo "npm start">>startTransformer.sh
    chmod +x startTransformer.sh    
}

configFront() {
    cd $basePath
    echo "#!/bin/bash">>startLiquidEtlFront.sh
    echo "cd $basePath/$liquidetlfrontend">>startLiquidEtlFront.sh
    echo "http-server -p$frontPort">>startLiquidEtlFront.sh
    chmod +x startLiquidEtlFront.sh    
}

installGlobalDependencies() {    
    npm install -g pm2
    npm install -g http-server
}

openPorts() {
    firewall-cmd --permanent --add-port=$apiCargasPort/tcp
    firewall-cmd --permanent --add-port=$apiTransformationPort/tcp
    firewall-cmd --permanent --add-port=$frontPort/tcp
    firewall-cmd --reload
}

cloneRepo() {
  cd $basePath

  yum install unzip -y

  echo "Download from: $artifactoryRepo"

  curl -uadmin:$userArtifactoryToken -O "$artifactoryRepo/$repo_cliente/$liquidApiCargaRepo"
  curl -uadmin:$userArtifactoryToken -O "$artifactoryRepo/$repo_cliente/$liquidApiTransformerRepo"
  curl -uadmin:$userArtifactoryToken -O "$artifactoryRepo/$repo_cliente/$liquidFrontRepo"

  unzip $liquidApiCargaRepo -d $basePath/$liquidetlapicargas
  unzip $liquidApiTransformerRepo -d $basePath/$liquidetltransformer
  unzip $liquidFrontRepo -d $basePath/$liquidetlfrontend
}

installPackages() {
    cd $basePath/$liquidetlapicargas
    npm install -y
    cd $basePath/$liquidetltransformer
    npm install -y
    
    cd $basePath
}

installOracleClient() {
    cd $basePath

    if [ "$instalarOracle" == "s" ]    
    then
        echo "Download fro $artifactoryRepo"
        curl -uadmin:$userArtifactoryToken -O "$artifactoryRepo/$clientOracle11g"

        echo "Install Oracle Client 11.2"
        yum install $clientOracle11g -y
        oracleClientPath=/usr/lib/oracle/11.2/client64

        sh -c "echo $oracleClientPath/lib > \
        /etc/ld.so.conf.d/oracle-instantclient.conf"
        ldconfig

        export LD_LIBRARY_PATH=$oracleClientPath/lib:$LD_LIBRARY_PATH
        export PATH=$oracleClientPath/bin:$PATH    
    fi    
}

createBaseFolder() {
    mkdir -p $basePath
    chmod 755 $basePath
    cd $basePath

    fileRepoPath="$basePath/liquidEtlFileRepository"
    mkdir -p $fileRepoPath

    chmod 755 $fileRepoPath
}

#####MAIN######
read -rep $'Informe a versão do Oracle Linux [6/7] \n' versaoSO
read -rep $"Informe o local de instalação da aplicação [$basePath] " basePath
#if [ -z "$basePath" ] && basePath=/root/datapar/etl
read -rep $'Informe o endereco da base oracle [oracle-desenv-11g.vm.datapar.com/DOPR] \n' baseOracle
#if [ -z "$basePath" ] && basePath=oracle-desenv-11g.vm.datapar.com/DOPR
read -rep $'Informe a porta da Api Carga [3000]  \n' apiCargasPort
#if [ -z "$apiCargasPort" ] && apiCargasPort=3000
read -rep $'Informe a porta da Api de Transformation [3450] \n' apiTransformationPort
#if [ -z "$apiTransformationPort" ] && apiTransformationPort=3450
read -rep $'Informe a porta da aplicacao frontend [7000] \n' frontPort
#if [ -z "$frontPort" ] && frontPort=7000
read -rep $'Instalar Nodejs v.10 ? [N/s] \n' instalarNode
#if [ -z "$instalarNode" ] && instalarNode=N
read -rep $'Instalar Oracle Client [N/s] ? \n' instalarOracle
#if [ -z "$oracleVersion" ] && oracleVersion=N

createBaseFolder

installOracleClient

doInstallNode

cloneRepo

installPackages

installGlobalDependencies

configApiCarga

configApiTransformation

configFront

openPorts

createEnvironmentFile

startServices