"use strict";

const express = require("express")
const router = express.Router()
const controller = require('../controllers/consulta-controller')
const variables = require('../bin/configuration/variables')
const auth = require('../middlewares/authentication')

let _controller = new controller()

// rotas passando x-access-token
router.get(`/${variables.Module.planoFinanciamento}`, auth, _controller.getPlano)
router.get(`/${variables.Module.planoFinanciamento}/:id`, auth, _controller.getPlanoById)
router.get(`/${variables.Module.mercadoria}`, auth, _controller.getMercadoria)
router.get(`/${variables.Module.mercadoria}/:id`, auth, _controller.getMercadoriaById)
router.get(`/${variables.Module.localidade}`, auth, _controller.getLocalidade)
router.get(`/${variables.Module.localidade}/:id`, auth, _controller.getLocalidadeById)
router.get(`/${variables.Module.variedade}`, auth, _controller.getVariedade)
router.get(`/${variables.Module.variedade}/:id`, auth, _controller.getVariedadeById)
router.get(`/${variables.Module.silo}`, auth, _controller.getSilo)
router.get(`/${variables.Module.silo}/:id`, auth, _controller.getSiloById)
router.get(`/${variables.Module.entidade}`, auth, _controller.getEntidade)
router.get(`/${variables.Module.entidade}/:id`, auth, _controller.getEntidadeById)
router.get(`/${variables.Module.processo}`, auth, _controller.getProcesso)
router.get(`/${variables.Module.processo}/:token`, auth, _controller.getProcessoById)
router.get(`/${variables.Module.tipoCargas}`, auth, _controller.getTipoCargas)
router.get(`/${variables.Module.tipoCargas}/:id`, auth, _controller.getTipoCargasById)
router.get(`/${variables.Module.entidadeAnalista}`, auth, _controller.getAnalistaCargas)
// rotas passando schema
router.get(`/${variables.Module.schema}`, _controller.getSchema)
router.get(`/${variables.Module.filial}`, _controller.getFilial)
router.get(`/${variables.Module.filial}/:id`, _controller.getFilialById)
router.get(`/${variables.Module.departamento}`, _controller.getDepartamento)
router.get(`/${variables.Module.departamento}/:id`, _controller.getDepartamentoById)

/**
 * @swagger
 * /consulta/plan-financiacion:
 *   get:
 *     name: Plan de Financiación
 *     summary: Retorna una lista de Planes de Financiación
 *     produces:
 *       - application/json
 *     responses:
 *       '200':
 *         description: Planes retornados con suceso
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/'
 *       '404':
 *         description: No existen planes
 * /consulta/plan-financiacion/{id}:
 *   get:
 *     name: Busca un Plan de Financiación
 *     summary: Retorna un Plan de Financiación de acuerdo a un ID
 *     consumes:
 *       - number
 *     produces:
 *       - application/json
 *     parameters:
 *       - in: path
 *         name: id
 *         description: ID del Plan de Financiación
 *         schema:
 *           type: integer
 *           format: int64
 *         required:
 *           - true
 *     responses:
 *       '200':
 *         description: Plan retornado con suceso
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/'
 *       '404':
 *          description: Plan de Financiación no encontrado
 */
module.exports = router
